#!/bin/sh
# usr/opt/wrdapp/wspro/test/test.sh -- run wspro test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop]] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          06/17/92, rsregan, modified for use iwth wspro
#


#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROG=$TOPDIR/bin/wspro88
  DIVD=========================================

#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-7}                             # by default, stop at 7
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=7 ; fi
  if [ $Start -gt 7 -o $Stop -gt 7 ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - 7"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Start -gt 7 ] ; then Start=7 ; fi
    if [ $Stop -gt 7 ] ; then Stop=7 ; fi
    echo "Tests $Start - $Stop will be preformed"
    echo
  fi

#
# begin test runs
#
  echo
  echo $DIVD$DIVD
  echo "Begin processing WSPRO test runs $Start to $Stop"
  echo
  date

  $CLEAN

  Test=$Start

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    if [ $Test -eq 1 ] ; then  echo "data set ex1" ; fi
    if [ $Test -eq 2 ] ; then  echo "data set ex2" ; fi
    if [ $Test -eq 3 ] ; then  echo "data set ex4" ; fi
    if [ $Test -eq 4 ] ; then  echo "dry creek example" ; fi
    if [ $Test -eq 5 ] ; then  echo "steep creek example" ; fi
    if [ $Test -eq 6 ] ; then  echo "data set myprob" ; fi
    if [ $Test -eq 7 ] ; then  echo "some creek example" ; fi
    echo
    rm -f go
    Name=wspro$Test
    echo $DATA/$Name.dat > go
    echo $Name.out >> go
    $PROG < go > $Name.log

    Test=`expr $Test + 1`
  done
#
  echo
  echo
  echo $DIVD$DIVD
  echo "Completed WSPRO test runs $Start to $Stop"
  echo
# check output against original output in $DATA directory
  $CHECK wspro
